@@ -59,11 +59,11 @@ Window_Test::Window_Test()
   m_VBox.pack_end(m_Button_AddMainDir, Gtk::PACK_SHRINK);
 
   //Connect button signals:
-  m_Button_Quit.signal_clicked().connect(SigC::slot(*this, &Window_Test::on_Button_Quit));
-  m_Button_RemoveSubDir.signal_clicked().connect(SigC::slot(*this, &Window_Test::on_Button_RemoveSubDir));
-  m_Button_AddSubDir.signal_clicked().connect(SigC::slot(*this, &Window_Test::on_Button_AddSubDir));
-  m_Button_RemoveMainDir.signal_clicked().connect(SigC::slot(*this, &Window_Test::on_Button_RemoveMainDir));
-  m_Button_AddMainDir.signal_clicked().connect(SigC::slot(*this, &Window_Test::on_Button_AddMainDir));
+  m_Button_Quit.signal_clicked().connect(sigc::mem_fun(*this, &Window_Test::on_Button_Quit));
+  m_Button_RemoveSubDir.signal_clicked().connect(sigc::mem_fun(*this, &Window_Test::on_Button_RemoveSubDir));
+  m_Button_AddSubDir.signal_clicked().connect(sigc::mem_fun(*this, &Window_Test::on_Button_AddSubDir));
+  m_Button_RemoveMainDir.signal_clicked().connect(sigc::mem_fun(*this, &Window_Test::on_Button_RemoveMainDir));
+  m_Button_AddMainDir.signal_clicked().connect(sigc::mem_fun(*this, &Window_Test::on_Button_AddMainDir));
 
 
   Gtk::HBox* pBox = 0;
@@ -127,11 +127,11 @@ Gtk::HBox* Window_Test::create_entry_attached_to(const Glib::ustring& key)
   pEntry->set_text( m_refClient->get_string(key) );
 
   //Connect callback and remember the ID for later:
-  guint notify_id = m_refClient->notify_add(key, SigC::bind<Gtk::Entry*>(SigC::slot(*this, &Window_Test::Client_notify_func), pEntry));
+  guint notify_id = m_refClient->notify_add(key, sigc::bind<Gtk::Entry*>(sigc::mem_fun(*this, &Window_Test::Client_notify_func), pEntry));
   m_listNotifyIDs.push_back(notify_id);
 
-  pEntry->signal_changed().connect(SigC::bind(
-                            SigC::slot(*this, &Window_Test::on_Entry_changed),
+  pEntry->signal_changed().connect(sigc::bind(
+                            sigc::mem_fun(*this, &Window_Test::on_Entry_changed),
                             pEntry,
                             key)
                          );
@@ -184,7 +184,7 @@ void Window_Test::on_Button_AddMainDir()
 }
 
 //notify callback.
-//The Gtk::Entry* pEntry callback is extra. I used SigC::Bind in the connection.
+//The Gtk::Entry* pEntry callback is extra. I used sigc::bind in the connection.
 void Window_Test::Client_notify_func(guint cnxn_id, Gnome::Conf::Entry conf_entry, Gtk::Entry* pEntry)
 {
   if(pEntry)
